pub struct GeoJSONFormatter;Expand description
Format the results as a geojson file TODO there is probably a better way to do this using geozero to process the dataframe to a file without having to construct the entire thing in memory first