pub struct Metadata {
pub metrics: DataFrame,
pub geometries: DataFrame,
pub source_data_releases: DataFrame,
pub data_publishers: DataFrame,
pub countries: DataFrame,
}Expand description
The metadata struct contains the polars DataFrames for
the various different metadata tables. Can be constructed
from a single CountryMetadataLoader or for all countries.
It also provides the various functions for searching and
getting MetricRequests from the catalogue.
Fields
metrics: DataFramegeometries: DataFramesource_data_releases: DataFramedata_publishers: DataFramecountries: DataFrameImplementations
Sourceimpl Metadata
impl Metadata
Sourcepub fn combined_metric_source_geometry(&self) -> ExpandedMetadata
pub fn combined_metric_source_geometry(&self) -> ExpandedMetadata
Generate a Lazy DataFrame which joins the metrics, source and geometry metadata