pub struct SearchText {
pub text: String,
pub context: NonEmpty<SearchContext>,
pub config: SearchConfig,
}Fields
text: Stringcontext: NonEmpty<SearchContext>config: SearchConfigTrait Implementations
Sourceimpl Clone for SearchText
impl Clone for SearchText
Sourcefn clone(&self) -> SearchText
fn clone(&self) -> SearchText
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchText
impl Debug for SearchText
Sourceimpl Default for SearchText
impl Default for SearchText
Sourceimpl<'de> Deserialize<'de> for SearchText
impl<'de> Deserialize<'de> for SearchText
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<SearchText> for Expr
Implementing conversion from SearchText to a polars expression enables a
SearchText to be passed to polars dataframe for filtering results.
impl From<SearchText> for Expr
Implementing conversion from SearchText to a polars expression enables a
SearchText to be passed to polars dataframe for filtering results.
Sourcefn from(val: SearchText) -> Self
fn from(val: SearchText) -> Self
Converts to this type from the input type.